@@ -4,19 +4,12 @@
 
 """Bridge
 
-Bridge Component to Bridge one or more components in a single System.
-That is, events in System A bridged to System B are shared. For example:
+The Bridge Component is used for inter-process communications between
+processes. Bridge is used internally when a Component is started in
+"process mode" via :meth:`circuits.core.manager.start`. Typically a
+Pipe is used as the socket transport between two sides of a Bridge
+(*there must be a :class:`~Bridge` instnace on both sides*).
 
-A <--> Bridge <--> B
-
-Events that propagate in A, will propagate to B across the Bridge.
-Events that propagate in B, will propagate to A across the Bridge.
-
-When the Bridge is created, it will automatically attempt to send a
-Helo Event to any configured nodes or on a broadcast address if no
-nodes are initially configured. The default Bridge implementation
-uses the UDP protocol and as such events cannot be guaranteed of their
-order or delivery.
 """
 
 try:
@@ -56,7 +49,7 @@ class Bridge(BaseComponent):
     def _process_packet(self, eid, obj):
         if isinstance(obj, Event):
             obj.remote = True
-            obj.notify = "ValueChanged"
+            obj.notify = "value_changed"
             value = self.fire(obj)
             self._values[value] = eid
         elif isinstance(obj, Value):
@@ -87,5 +80,5 @@ class Bridge(BaseComponent):
         if event.name in self.ignore or getattr(event, "remote", False):
             return
 
-        event.notify = "ValueChanged"
+        event.notify = "value_changed"
         self.send(event)
