@@ -2,11 +2,14 @@
 .. codeauthor: mnl
 """
 
+
+from sys import stderr
 from threading import Event
+from signal import SIGINT, SIGTERM
+
 
 from .handlers import handler
 from .components import BaseComponent
-import sys
 from circuits.core.handlers import reprhandler
 
 
@@ -16,7 +19,7 @@ class FallBackGenerator(BaseComponent):
         super(FallBackGenerator, self).__init__(*args, **kwargs)
         self._continue = Event()
 
-    @handler("generate_events", priority=-100, filter=True)
+    @handler("generate_events", priority=-100)
     def _on_generate_events(self, event):
         """
         Fall back handler for the :class:`~.events.GenerateEvents` event.
@@ -24,13 +27,14 @@ class FallBackGenerator(BaseComponent):
         When the queue is empty a GenerateEvents event is fired, here
         we sleep for as long as possible to avoid using extra cpu cycles.
 
-        A poller would overwrite with with a higher priority filter, e.g.
-        @handler("generate_events", priority=0, filter=True)
+        A poller would override this with a higher priority handler.
+        e.g: ``@handler("generate_events", priority=0)``
         and provide a different way to idle when the queue is empty.
         """
+
         with event.lock:
             if event.time_left == 0:
-                return True
+                event.stop()
             self._continue.clear()
 
         if event.time_left > 0:
@@ -43,7 +47,7 @@ class FallBackGenerator(BaseComponent):
             # reduce_time_left(0) has been called. So calling this
             # here is OK in any case.
             event.reduce_time_left(0)
-            return True
+            event.stop()
 
         while event.time_left < 0:
             # If we get here, there was no work left to do when creating
@@ -55,7 +59,7 @@ class FallBackGenerator(BaseComponent):
             # Python ignores signals when waiting without timeout.
             self._continue.wait(10000)
 
-        return True
+        event.stop()
 
     def resume(self):
         """
@@ -67,13 +71,14 @@ class FallBackGenerator(BaseComponent):
 
 class FallBackErrorHandler(BaseComponent):
     """
-    If ther is no handler for error events in the component hierarchy, this
+    If there is no handler for error events in the component hierarchy, this
     component's handler is added automatically. It simply prints
     the error information on stderr.
     """
 
     @handler("error", channel="*")
-    def _on_error(self, error_type, value, traceback, handler=None):
+    def _on_error(self, error_type, value, traceback,
+                  handler=None, fevent=None):
         s = []
 
         if handler is None:
@@ -81,8 +86,24 @@ class FallBackErrorHandler(BaseComponent):
         else:
             handler = reprhandler(handler)
 
-        msg = "ERROR %s (%s): %s\n" % (handler, error_type, value)
+        msg = "ERROR {0:s} ({1:s}) ({2:s}): {3:s}\n".format(
+            handler, repr(fevent), repr(error_type), repr(value)
+        )
+
         s.append(msg)
         s.extend(traceback)
         s.append("\n")
-        sys.stderr.write("".join(s))
+        stderr.write("".join(s))
+
+
+class FallBackSignalHandler(BaseComponent):
+    """
+    If there is no handler for signal events in the component hierarchy, this
+    component's handler is added automatically. It simply terminates the
+    system if the signal is SIGINT or SIGTERM.
+    """
+
+    @handler("signal", channel="*")
+    def _on_signal(self, signo, stack):
+        if signo in [SIGINT, SIGTERM]:
+            raise SystemExit(0)
