@@ -12,8 +12,8 @@ from os import getpid
 from circuits import Component, Event
 
 
-class Hello(Event):
-    """Hello Event"""
+class hello(Event):
+    """hello Event"""
 
 
 class App(Component):
@@ -24,13 +24,17 @@ class App(Component):
 
 def test(manager, watcher):
     app = App()
-    app.start(process=True, link=manager)
-    assert watcher.wait("ready")
+    process, bridge = app.start(process=True, link=manager)
+    assert watcher.wait("ready", timeout=30)
 
-    x = manager.fire(Hello())
+    x = manager.fire(hello())
 
     assert pytest.wait_for(x, "result")
 
     assert x.value == "Hello from {0:d}".format(app.pid)
 
     app.stop()
+    app.join()
+
+    bridge.unregister()
+    watcher.wait("unregistered")
